
.. _`Exceptions`:

Exceptions
----------

.. automodule:: pywbem._exceptions

.. autoclass:: pywbem.ConnectionError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.AuthError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.HTTPError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.TimeoutError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.ParseError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.CIMXMLParseError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.XMLParseError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.HeaderParseError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.CIMError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.ModelError
    :members:
    :autosummary:
    :autosummary-inherited-members:

.. autoclass:: pywbem.Error
    :members:
    :autosummary:
    :autosummary-inherited-members:
